# File Registry
version 0.0.5
addad pandas as a requirement
version 0.0.3
added wordanalysis for __init__

version 0.0.2
added rootpath for __init__

version 0.0.1
Basic version 

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.